@@ -44,13 +44,14 @@ def define_structure(string, format_type):
 
 
 class SparkEngine(SqlEngine):
+
     def __init__(self, spark: SparkSession, env_variables: dict):
         super().__init__(env_variables)
         self._spark = spark
 
     def verify_target_dataset(self):
         for (table, dataset) in self.target_dataset:
-            result_df = self._query_table(table)
+            result_df = self.query_table(table)
             assert_frame_equal(result_df, dataset, sort_keys=dataset.columns.values.tolist())
 
     def _execute(self, statements: List[str]):
@@ -65,10 +66,10 @@ class SparkEngine(SqlEngine):
 
     def get_target_tables(self) -> List[Tuple[str, pd.DataFrame]]:
         for (table, dataset) in self.target_dataset:
-            yield table, self._query_table(table)
+            yield table, self.query_table(table)
 
-    def _query_table(self, table):
-        return self._spark.sql(f"SELECT * FROM {table}").toPandas()
+    def query_table(self, table_name: str):
+        return self._spark.sql(f"SELECT * FROM {table_name}").toPandas()
 
     def _register_temp_view(self, datasets: List[Tuple[str, pd.DataFrame]]):
         for (table, dataset) in datasets:
